#ifndef _RFLEX_STRUCT_H
#define _RFLEX_STRUCT_H

/* ------------------------------------------------------------
 * Compatibility
 */

#include "genPosStruct.h"

#define RFLEX_POSTER_NAME GENPOS_POSTER_NAME
#define RFLEX_ROBOT_ODO_STR GENPOS_CART_STATE
#define RFLEX_ERROR_ODO_STR GENPOS_CART_CONFIG_VAR
#define RFLEX_SET_ERR_STR GENPOS_CART_CONFIG_VAR
#define RFLEX_SPEED_REF GENPOS_CART_SPEED
#define RFLEX_FORWARD_MOTION GENPOS_FORWARD_MOTION
#define RFLEX_BACKWARD_MOTION GENPOS_BACKWARD_MOTION
#define RFLEX_MOTION_DIRECTION GENPOS_MOTION_DIRECTION
#define RFLEX_REF_STR GENPOS_CART_REF
#define RFLEX_CMD_PARAM_STR GENPOS_CART_CMD_PARAM
#define RFLEX_TRACK_MODE GENPOS_TRACK_MODE
#define RFLEX_TRACK_STR GENPOS_TRACK



typedef struct RFLEX_STRING {
  char name[32];
} RFLEX_STRING;







/* ------------------------------------------------------------
 * PoM tagging 
 */
typedef enum RFLEX_POM_TAGGING {
   RFLEX_ENABLE_POMTAGS,
   RFLEX_DISABLE_POMTAGS

#define RFLEX_DEFAULT_TAGGING		RFLEX_DISABLE_POMTAGS
} RFLEX_POM_TAGGING;


/* ------------------------------------------------------------
 * Connection to the rFlex micro-controller status
 */
typedef enum RFLEX_CLIENT_STATUS {
	RFLEX_NOT_CONNECTED,
	RFLEX_CONNECTED
} RFLEX_CLIENT_STATUS;

typedef struct RFLEX_CLIENT_STR {
	char deviceName[16];		/* device name - /dev/ttyR0 */
	int baudRate;			/* speed - 115200 */
} RFLEX_CLIENT_STR;

typedef enum RFLEX_MODE {
	MANUAL_MODE,
	AUTO_MODE
} RFLEX_MODE;

/* Raw rFlex axis data */
typedef struct RFLEX_RAW_AXIS_STR {
	int pos;
	int vel;
	int acc;
	int trq;
} RFLEX_RAW_AXIS_STR;

/* Coefficient proportionnel a la vitesse pour calculer l'erreur sur 
   le deplacement des roues */
typedef struct RFLEX_VAR_PARAMS {
	double coeffLin;
	double coeffAng;
	double coeffLinAng;
} RFLEX_VAR_PARAMS;


/* Geometrical parameters */
typedef struct RFLEX_GEOM_PARAM_STR {
  double linMToStep;
  double angRadToStep;
  double linStepToM;
  double angStepToRad;
  double sonarScale;
  double sonarOffset;
} RFLEX_GEOM_PARAM_STR;


/* a GENPOS_CART_STATE-like struct in 3D */
/* Same thing with 4 more elements: z,zC,pitch,roll */
typedef struct RFLEX_CART_3DSTATE {
  double xRef;                  /* position  */
  double yRef;                  /* control point */
  double zRef;
  double xRob;                 /* position */
  double yRob;                 /* robot center */
  double zRob;
  double theta;              /* robot orientation*/
  double pitch;              /* robot's pitch (site) */
  double roll;               /* robot's roll (gite) */
  double v;                  /* linear velocity */
  double vt;
  double w;                  /* angular velocity */
} RFLEX_CART_3DSTATE;

typedef struct RFLEX_CART_3DCONFIG {
  double x;
  double y;
  double z;
  double theta;
} RFLEX_CART_3DCONFIG;


/* Set of --3D-- odometric data */
typedef struct RFLEX_ODO_STR {
        RFLEX_CART_3DSTATE robot;
  /* The following structure should be changed, to integrate the new vars due to 3D */
	GENPOS_CART_CONFIG_VAR odoError;
} RFLEX_ODO_STR;

typedef struct RFLEX_MISC_ODO {
  double s;     /* curvilinear abcsissa (from rflex start) */
  long int sInit;  /* curvilinear abcsissa (record from file) */
} RFLEX_MISC_ODO;

/* ------------------------------------------------------------
 *  Proxymetry sensors
 */

/* Number of sonars */

#ifdef ATRV_JUNIOR
#define RFLEX_NMAX_SENSORS 17
#elif defined(ATRV)
#define RFLEX_NMAX_SENSORS 12
#elif defined(B21R)
#define RFLEX_NMAX_SENSORS 48
#else
#error "No robot defined"
#endif

/* sensor coordinates in the robot frame */
typedef struct RFLEX_CONFIG {
	double x;
	double y;
	double theta;
} RFLEX_CONFIG;

typedef struct RFLEX_SONARS_CONFIG {
	RFLEX_CONFIG tab[RFLEX_NMAX_SENSORS];
} RFLEX_SONARS_CONFIG;

/* Measure points in the local robot frame */
typedef struct RFLEX_POINT {
	double x;
	double y;
} RFLEX_POINT;

typedef struct RFLEX_SONARS_CART_MEASURES {
	RFLEX_POINT tab[RFLEX_NMAX_SENSORS];
} RFLEX_SONARS_CART_MEASURES;

typedef struct RFLEX_SONARS_RANGE {
	double tab[RFLEX_NMAX_SENSORS];
} RFLEX_SONARS_RANGE;


/* ------------------------------------------------------------
 * System status 
 */

typedef enum RFLEX_BATTERY_STATUS {
  RFLEX_BATTERY_LOW,
  RFLEX_BATTERY_MEDIUM,
  RFLEX_BATTERY_HIGH
} RFLEX_BATTERY_STATUS;
  
typedef struct RFLEX_SYSTEM_STATE_STR {
        RFLEX_MODE mode;
	int brake;
        int shock;
        RFLEX_BATTERY_STATUS batteryStatus;
	double batteryLevel;
        double highBatteryLevel; /* Interesting for the measure on the web interface */
        double mediumBatteryLevel; /* Interesting for the measure on the web interface */
        double lowBatteryLevel; /* Interesting for the measure on the web interface */
} RFLEX_SYSTEM_STATE_STR;


/* ------------------------------------------------------------
 * Joystick
 */
typedef struct RFLEX_JOYSTICK_STR {
	int x;
	int y;
	int buttons;
        int unused;
} RFLEX_JOYSTICK_STR;

/* Buttons values */
#define RFLEX_JOYSTICK_BUTTON1 0x01
#define RFLEX_JOYSTICK_BUTTON2 0x02


/* ------------------------------------------------------------ 
 * door's switch and infra reds sensors
 */
#ifdef B21R
/*
 * door's switch
 */
#define RFLEX_NB_DOORS 14
#define RFLEX_NB_DOOR_SWITCHS 4
typedef struct RFLEX_DOORS_SWITCH {
        short tab[RFLEX_NB_DOORS][RFLEX_NB_DOOR_SWITCHS];
} RFLEX_DOORS_SWITCH;

#define RFLEX_NB_INFRA_REDS 24
typedef struct RFLEX_INFRA_REDS {
        int tab[RFLEX_NB_INFRA_REDS];
} RFLEX_INFRA_REDS;



#endif /* B21R */


/* ------------------------------------------------------------ 
 * gyro
 */

typedef enum RFLEX_GYRO_MODE {
  RFLEX_GYRO_OFF,
  RFLEX_GYRO_ON_IF_MOTION,
  RFLEX_GYRO_ON
} RFLEX_GYRO_MODE;

typedef struct RFLEX_GYRO_PARAMS {
  RFLEX_GYRO_MODE mode;
  int unused;
  char port[32];
} RFLEX_GYRO_PARAMS;

typedef struct RFLEX_GYRO {
  RFLEX_GYRO_PARAMS params;
  int initDone;
  int gyroOn;
  RFLEX_GYRO_MODE currentMode;
  int unused;
  double gyroToRobotOffset;
  double gyroTheta;
  double robotTheta;
} RFLEX_GYRO;


/* ------------------------------------------------------------ */
/* Odometry Method: Could be defined only on ATRV and ATRV_JUNIOR */

typedef enum RFLEX_ODOMETRY_MODE {
  RFLEX_ODO_2D, /* Standard 2D odometry */
  RFLEX_ODO_3D  /* 3D odometry using Attitude Estimation provided by IMU */
} RFLEX_ODOMETRY_MODE;

#define	RFLEX_MAX_STRLEN	64
#define RFLEX_DEFAULT_ATTITUDE_POSTER "imuAttitudeEstimation"

typedef struct RFLEX_ODOMETRY_METHOD {
  RFLEX_ODOMETRY_MODE mode;
  int unused;
  char attitudePosterName[RFLEX_MAX_STRLEN];
} RFLEX_ODOMETRY_METHOD;

#endif
