
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef rflex_POSTER_LIB_H
#define rflex_POSTER_LIB_H

#include "posterLib.h"
#include "genom/genom.h"

/* Types definis ou utilises par le module */
#include "rflexType.h"
#include "rflexError.h"

/* 
 * Definition de la SDI_C 
*/
typedef struct {
  CNTRL_TASK_DESCRIPTION cntrlTask;
  EXEC_TASK_DESCRIPTION execTaskTab[RFLEX_NB_EXEC_TASK];
  ACTIVITY_DESCRIPTION activityTab[MAX_ACTIVITIES];
} RFLEX_CNTRL_STR;

/* For consistency with other posters */
typedef RFLEX_CNTRL_STR RFLEX_CNTRL_POSTER_STR;
 
/* 
 * Definition des structures de posters
 */
#include "rflexPosterLibStruct.h"



/* Posters */
#define RFLEX_CNTRL_POSTER_NAME genomInstanceSuffixName("rflex", "Cntrl")
#define RFLEX_ROBOT_POSTER_NAME genomInstanceSuffixName("rflex", "Robot")
#define RFLEX_MEPOS_POSTER_NAME genomInstanceSuffixName("rflex", "MEPos")
#define RFLEX_SONARSCONFIG_POSTER_NAME genomInstanceSuffixName("rflex", "SonarsConfig")
#define RFLEX_SONARSRHO_POSTER_NAME genomInstanceSuffixName("rflex", "SonarsRho")
#define RFLEX_SONARSCART_POSTER_NAME genomInstanceSuffixName("rflex", "SonarsCart")


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif
extern STATUS rflexPosterInit ( void );
extern POSTER_ID rflexCntrlPosterID ();
extern STATUS rflexCntrlPosterRead ( RFLEX_CNTRL_STR *rflexCntrlStrId );
extern STATUS rflexCntrlPosterInit ( void );
extern STATUS rflexCntrlInstancePosterRead(const char *name, RFLEX_CNTRL_STR *rflexCntrlStrId);
extern STATUS rflexRobotPosterInit ( void );
extern POSTER_ID rflexRobotPosterID ( void );
extern STATUS rflexRobotPosterRead ( RFLEX_ROBOT_POSTER_STR *x );
extern STATUS rflexRobotInstancePosterRead ( const char *, RFLEX_ROBOT_POSTER_STR * );
extern STATUS rflexRobotPositionPosterRead ( RFLEX_CART_3DSTATE *Position );
extern STATUS rflexRobotPositionInstancePosterRead( const char *, RFLEX_CART_3DSTATE * );
extern STATUS rflexRobotrawAxisPosterRead ( RFLEX_RAW_AXIS_STR *rawAxis );
extern STATUS rflexRobotrawAxisInstancePosterRead( const char *, RFLEX_RAW_AXIS_STR * );
extern STATUS rflexRobotPosErrorPosterRead ( GENPOS_CART_CONFIG_VAR *PosError );
extern STATUS rflexRobotPosErrorInstancePosterRead( const char *, GENPOS_CART_CONFIG_VAR * );
extern STATUS rflexRobotconfigRefPosterRead ( GENPOS_CART_REF *configRef );
extern STATUS rflexRobotconfigRefInstancePosterRead( const char *, GENPOS_CART_REF * );
extern STATUS rflexRobotspeedRefPosterRead ( GENPOS_CART_SPEED *speedRef );
extern STATUS rflexRobotspeedRefInstancePosterRead( const char *, GENPOS_CART_SPEED * );
extern STATUS rflexRobotsystemStatePosterRead ( RFLEX_SYSTEM_STATE_STR *systemState );
extern STATUS rflexRobotsystemStateInstancePosterRead( const char *, RFLEX_SYSTEM_STATE_STR * );
extern STATUS rflexRobotmiscOdoPosterRead ( RFLEX_MISC_ODO *miscOdo );
extern STATUS rflexRobotmiscOdoInstancePosterRead( const char *, RFLEX_MISC_ODO * );
extern STATUS rflexMEPosPosterInit ( void );
extern POSTER_ID rflexMEPosPosterID ( void );
extern STATUS rflexMEPosPosterRead ( RFLEX_MEPOS_POSTER_STR *x );
extern STATUS rflexMEPosInstancePosterRead ( const char *, RFLEX_MEPOS_POSTER_STR * );
extern STATUS rflexMEPosPosPosterRead ( POM_ME_POS *Pos );
extern STATUS rflexMEPosPosInstancePosterRead( const char *, POM_ME_POS * );
extern STATUS rflexSonarsConfigPosterInit ( void );
extern POSTER_ID rflexSonarsConfigPosterID ( void );
extern STATUS rflexSonarsConfigPosterRead ( RFLEX_SONARSCONFIG_POSTER_STR *x );
extern STATUS rflexSonarsConfigInstancePosterRead ( const char *, RFLEX_SONARSCONFIG_POSTER_STR * );
extern STATUS rflexSonarsConfigConfigPosterRead ( RFLEX_SONARS_CONFIG *Config );
extern STATUS rflexSonarsConfigConfigInstancePosterRead( const char *, RFLEX_SONARS_CONFIG * );
extern STATUS rflexSonarsRhoPosterInit ( void );
extern POSTER_ID rflexSonarsRhoPosterID ( void );
extern STATUS rflexSonarsRhoPosterRead ( RFLEX_SONARSRHO_POSTER_STR *x );
extern STATUS rflexSonarsRhoInstancePosterRead ( const char *, RFLEX_SONARSRHO_POSTER_STR * );
extern STATUS rflexSonarsRhoRangePosterRead ( RFLEX_SONARS_RANGE *Range );
extern STATUS rflexSonarsRhoRangeInstancePosterRead( const char *, RFLEX_SONARS_RANGE * );
extern STATUS rflexSonarsCartPosterInit ( void );
extern POSTER_ID rflexSonarsCartPosterID ( void );
extern STATUS rflexSonarsCartPosterRead ( RFLEX_SONARSCART_POSTER_STR *x );
extern STATUS rflexSonarsCartInstancePosterRead ( const char *, RFLEX_SONARSCART_POSTER_STR * );
extern STATUS rflexSonarsCartMeasureInRobotCartPosterRead ( RFLEX_SONARS_CART_MEASURES *MeasureInRobotCart );
extern STATUS rflexSonarsCartMeasureInRobotCartInstancePosterRead( const char *, RFLEX_SONARS_CART_MEASURES * );
#ifdef __cplusplus
}
#endif
#endif

